@@ -1,8 +1,6 @@
-/* 
+/*
    +----------------------------------------------------------------------+
-   | PHP Version 5                                                        |
-   +----------------------------------------------------------------------+
-   | Copyright (c) 1997-2012 The PHP Group                                |
+   | Copyright (c) The PHP Group                                          |
    +----------------------------------------------------------------------+
    | This source file is subject to version 3.01 of the PHP license,      |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -16,14 +14,12 @@
    +----------------------------------------------------------------------+
  */
 
-/* $Id$ */
-
 #ifndef MOD_FILES_H
 #define MOD_FILES_H
 
-extern ps_module ps_mod_files;
+extern const ps_module ps_mod_files;
 #define ps_files_ptr &ps_mod_files
 
-PS_FUNCS(files);
+PS_FUNCS_UPDATE_TIMESTAMP(files);
 
 #endif
